@@ -17,6 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with Radicale.  If not, see <http://www.gnu.org/licenses/>.
 
+import datetime
+import os
 import ssl
 import sys
 from importlib import import_module, metadata
@@ -25,11 +27,15 @@ from typing import Callable, Sequence, Tuple, Type, TypeVar, Union
 from radicale import config
 from radicale.log import logger
 
+if sys.platform != "win32":
+    import grp
+    import pwd
+
 _T_co = TypeVar("_T_co", covariant=True)
 
 RADICALE_MODULES: Sequence[str] = ("radicale", "vobject", "passlib", "defusedxml",
-                                   "dateutil",
                                    "bcrypt",
+                                   "argon2-cffi",
                                    "pika",
                                    "ldap",
                                    "ldap3",
@@ -41,6 +47,10 @@ ADDRESS_TYPE = Union[Tuple[Union[str, bytes, bytearray], int],
                      Tuple[str, int, int, int]]
 
 
+# Max YEAR in datetime in unixtime
+DATETIME_MAX_UNIXTIME: int = (datetime.MAXYEAR - 1970) * 365 * 24 * 60 * 60
+
+
 def load_plugin(internal_types: Sequence[str], module_name: str,
                 class_name: str, base_class: Type[_T_co],
                 configuration: "config.Configuration") -> _T_co:
@@ -102,7 +112,7 @@ def ssl_context_options_by_protocol(protocol: str, ssl_context_options):
     ssl_context_options |= ssl.OP_NO_TLSv1_3
     logger.debug("SSL cleared SSL context options: '0x%x'", ssl_context_options)
     for entry in protocol.split():
-        entry = entry.strip('+') # remove trailing '+'
+        entry = entry.strip('+')  # remove trailing '+'
         if entry == "ALL":
             logger.debug("SSL context options, enable ALL (some maybe not supported by underlying OpenSSL, SSLv2 not enabled at all)")
             ssl_context_options &= ~ssl.OP_NO_SSLv3
@@ -162,7 +172,7 @@ def ssl_context_options_by_protocol(protocol: str, ssl_context_options):
 
 def ssl_context_minimum_version_by_options(ssl_context_options):
     logger.debug("SSL calculate minimum version by context options: '0x%x'", ssl_context_options)
-    ssl_context_minimum_version = ssl.TLSVersion.SSLv3 # default
+    ssl_context_minimum_version = ssl.TLSVersion.SSLv3  # default
     if ((ssl_context_options & ssl.OP_NO_SSLv3) and (ssl_context_minimum_version == ssl.TLSVersion.SSLv3)):
         ssl_context_minimum_version = ssl.TLSVersion.TLSv1
     if ((ssl_context_options & ssl.OP_NO_TLSv1) and (ssl_context_minimum_version == ssl.TLSVersion.TLSv1)):
@@ -172,7 +182,7 @@ def ssl_context_minimum_version_by_options(ssl_context_options):
     if ((ssl_context_options & ssl.OP_NO_TLSv1_2) and (ssl_context_minimum_version == ssl.TLSVersion.TLSv1_2)):
         ssl_context_minimum_version = ssl.TLSVersion.TLSv1_3
     if ((ssl_context_options & ssl.OP_NO_TLSv1_3) and (ssl_context_minimum_version == ssl.TLSVersion.TLSv1_3)):
-        ssl_context_minimum_version = 0 # all disabled
+        ssl_context_minimum_version = 0  # all disabled
 
     logger.debug("SSL context options: '0x%x' results in minimum version: %s", ssl_context_options, ssl_context_minimum_version)
     return ssl_context_minimum_version
@@ -180,7 +190,7 @@ def ssl_context_minimum_version_by_options(ssl_context_options):
 
 def ssl_context_maximum_version_by_options(ssl_context_options):
     logger.debug("SSL calculate maximum version by context options: '0x%x'", ssl_context_options)
-    ssl_context_maximum_version = ssl.TLSVersion.TLSv1_3 # default
+    ssl_context_maximum_version = ssl.TLSVersion.TLSv1_3  # default
     if ((ssl_context_options & ssl.OP_NO_TLSv1_3) and (ssl_context_maximum_version == ssl.TLSVersion.TLSv1_3)):
         ssl_context_maximum_version = ssl.TLSVersion.TLSv1_2
     if ((ssl_context_options & ssl.OP_NO_TLSv1_2) and (ssl_context_maximum_version == ssl.TLSVersion.TLSv1_2)):
@@ -214,3 +224,43 @@ def ssl_get_protocols(context):
         if (context.minimum_version <= ssl.TLSVersion.TLSv1_3) and (context.maximum_version >= ssl.TLSVersion.TLSv1_3):
             protocols.append("TLSv1.3")
     return protocols
+
+
+def user_groups_as_string():
+    if sys.platform != "win32":
+        euid = os.geteuid()
+        egid = os.getegid()
+        try:
+            username = pwd.getpwuid(euid)[0]
+        except Exception:
+            # name of user not found
+            s = "user=(%d) group=(%d)" % (euid, egid)
+            return s
+        gids = os.getgrouplist(username, egid)
+        groups = []
+        for gid in gids:
+            try:
+                gi = grp.getgrgid(gid)
+                groups.append("%s(%d)" % (gi.gr_name, gid))
+            except Exception:
+                groups.append("%s(%d)" % (gid, gid))
+        s = "user=%s(%d) groups=%s" % (username, euid, ','.join(groups))
+    else:
+        username = os.getlogin()
+        s = "user=%s" % (username)
+    return s
+
+
+def format_ut(unixtime: int) -> str:
+    if sys.platform == "win32":
+        # TODO check how to support this better
+        return str(unixtime)
+    if unixtime < DATETIME_MAX_UNIXTIME:
+        if sys.version_info < (3, 11):
+            dt = datetime.datetime.utcfromtimestamp(unixtime)
+        else:
+            dt = datetime.datetime.fromtimestamp(unixtime, datetime.UTC)
+        r = str(unixtime) + "(" + dt.strftime('%Y-%m-%dT%H:%M:%SZ') + ")"
+    else:
+        r = str(unixtime) + "(>MAX:" + str(DATETIME_MAX_UNIXTIME) + ")"
+    return r
